==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/kubernetesconfiguration/kotlin/inputs/PostBuildDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kubernetesconfiguration.kotlin.inputs

import com.pulumi.azurenative.kubernetesconfiguration.inputs.PostBuildDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * The postBuild definitions defining variable substitutions for this Kustomization after kustomize build.
 * @property substitute Key/value pairs holding the variables to be substituted in this Kustomization.
 * @property substituteFrom Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
 */
public data class PostBuildDefinitionArgs(
    public val substitute: Output<Map<String, String>>? = null,
    public val substituteFrom: Output<List<SubstituteFromDefinitionArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.kubernetesconfiguration.inputs.PostBuildDefinitionArgs> {
    override fun toJava():
        com.pulumi.azurenative.kubernetesconfiguration.inputs.PostBuildDefinitionArgs =
        com.pulumi.azurenative.kubernetesconfiguration.inputs.PostBuildDefinitionArgs.builder()
            .substitute(
                substitute?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .substituteFrom(
                substituteFrom?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [PostBuildDefinitionArgs].
 */
@PulumiTagMarker
public class PostBuildDefinitionArgsBuilder internal constructor() {
    private var substitute: Output<Map<String, String>>? = null

    private var substituteFrom: Output<List<SubstituteFromDefinitionArgs>>? = null

    /**
     * @param value Key/value pairs holding the variables to be substituted in this Kustomization.
     */
    @JvmName("cdeddcfjthiqetvx")
    public suspend fun substitute(`value`: Output<Map<String, String>>) {
        this.substitute = value
    }

    /**
     * @param value Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("vmanewgfamkwpdpc")
    public suspend fun substituteFrom(`value`: Output<List<SubstituteFromDefinitionArgs>>) {
        this.substituteFrom = value
    }

    @JvmName("asnusoqgovgyiyiy")
    public suspend fun substituteFrom(vararg values: Output<SubstituteFromDefinitionArgs>) {
        this.substituteFrom = Output.all(values.asList())
    }

    /**
     * @param values Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("cosjbbpbrpxxsjeg")
    public suspend fun substituteFrom(values: List<Output<SubstituteFromDefinitionArgs>>) {
        this.substituteFrom = Output.all(values)
    }

    /**
     * @param value Key/value pairs holding the variables to be substituted in this Kustomization.
     */
    @JvmName("vfygvstvfrmmerjc")
    public suspend fun substitute(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.substitute = mapped
    }

    /**
     * @param values Key/value pairs holding the variables to be substituted in this Kustomization.
     */
    @JvmName("knpkoikvkfipfueb")
    public fun substitute(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.substitute = mapped
    }

    /**
     * @param value Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("nhbyfwmjhaacxkef")
    public suspend fun substituteFrom(`value`: List<SubstituteFromDefinitionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.substituteFrom = mapped
    }

    /**
     * @param argument Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("yxbpuqcxpbbohhqt")
    public suspend
    fun substituteFrom(argument: List<suspend SubstituteFromDefinitionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SubstituteFromDefinitionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.substituteFrom = mapped
    }

    /**
     * @param argument Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("okxaquniceuyonnk")
    public suspend fun substituteFrom(
        vararg
        argument: suspend SubstituteFromDefinitionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SubstituteFromDefinitionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.substituteFrom = mapped
    }

    /**
     * @param argument Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("twvhkseqdugpfeiv")
    public suspend
    fun substituteFrom(argument: suspend SubstituteFromDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SubstituteFromDefinitionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.substituteFrom = mapped
    }

    /**
     * @param values Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("wbddtfdmrptqrptw")
    public suspend fun substituteFrom(vararg values: SubstituteFromDefinitionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.substituteFrom = mapped
    }

    internal fun build(): PostBuildDefinitionArgs = PostBuildDefinitionArgs(
        substitute = substitute,
        substituteFrom = substituteFrom,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/kubernetesconfiguration/kotlin/inputs/PostBuildDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kubernetesconfiguration.kotlin.inputs

import com.pulumi.azurenative.kubernetesconfiguration.inputs.PostBuildDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * The postBuild definitions defining variable substitutions for this Kustomization after kustomize build.
 * @property substitute Key/value pairs holding the variables to be substituted in this Kustomization.
 * @property substituteFrom Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
 */
public data class PostBuildDefinitionArgs(
    public val substitute: Output<Map<String, String>>? = null,
    public val substituteFrom: Output<List<SubstituteFromDefinitionArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.kubernetesconfiguration.inputs.PostBuildDefinitionArgs> {
    override fun toJava():
        com.pulumi.azurenative.kubernetesconfiguration.inputs.PostBuildDefinitionArgs =
        com.pulumi.azurenative.kubernetesconfiguration.inputs.PostBuildDefinitionArgs.builder()
            .substitute(
                substitute?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .substituteFrom(
                substituteFrom?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [PostBuildDefinitionArgs].
 */
@PulumiTagMarker
public class PostBuildDefinitionArgsBuilder internal constructor() {
    private var substitute: Output<Map<String, String>>? = null

    private var substituteFrom: Output<List<SubstituteFromDefinitionArgs>>? = null

    /**
     * @param value Key/value pairs holding the variables to be substituted in this Kustomization.
     */
    @JvmName("otsgvvjugpuhsbxt")
    public suspend fun substitute(`value`: Output<Map<String, String>>) {
        this.substitute = value
    }

    /**
     * @param value Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("owkbkrwwbeyuggwt")
    public suspend fun substituteFrom(`value`: Output<List<SubstituteFromDefinitionArgs>>) {
        this.substituteFrom = value
    }

    @JvmName("jxgsoaksvxxmwldg")
    public suspend fun substituteFrom(vararg values: Output<SubstituteFromDefinitionArgs>) {
        this.substituteFrom = Output.all(values.asList())
    }

    /**
     * @param values Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("wbygrrbbnjkjwebb")
    public suspend fun substituteFrom(values: List<Output<SubstituteFromDefinitionArgs>>) {
        this.substituteFrom = Output.all(values)
    }

    /**
     * @param value Key/value pairs holding the variables to be substituted in this Kustomization.
     */
    @JvmName("icpaahetuwmfmeky")
    public suspend fun substitute(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.substitute = mapped
    }

    /**
     * @param values Key/value pairs holding the variables to be substituted in this Kustomization.
     */
    @JvmName("qvqitstqowwkfpmw")
    public fun substitute(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.substitute = mapped
    }

    /**
     * @param value Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("nmpshxmmjinbygui")
    public suspend fun substituteFrom(`value`: List<SubstituteFromDefinitionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.substituteFrom = mapped
    }

    /**
     * @param argument Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("qjqjkdotixrklbly")
    public suspend
    fun substituteFrom(argument: List<suspend SubstituteFromDefinitionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SubstituteFromDefinitionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.substituteFrom = mapped
    }

    /**
     * @param argument Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("gwekmihochbeijoy")
    public suspend fun substituteFrom(
        vararg
        argument: suspend SubstituteFromDefinitionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SubstituteFromDefinitionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.substituteFrom = mapped
    }

    /**
     * @param argument Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("chltpvgilcurkvwi")
    public suspend
    fun substituteFrom(argument: suspend SubstituteFromDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SubstituteFromDefinitionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.substituteFrom = mapped
    }

    /**
     * @param values Array of ConfigMaps/Secrets from which the variables are substituted for this Kustomization.
     */
    @JvmName("cykandqgsrkhlvfm")
    public suspend fun substituteFrom(vararg values: SubstituteFromDefinitionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.substituteFrom = mapped
    }

    internal fun build(): PostBuildDefinitionArgs = PostBuildDefinitionArgs(
        substitute = substitute,
        substituteFrom = substituteFrom,
    )
}
